==> qtjambi-quick-debuginfo-macos-5.15.18.jar: sources/QtJambiQuick/QSGMaterialShader_shell.h <==
#ifndef QSGMATERIALSHADER_SHELL_H
#define QSGMATERIALSHADER_SHELL_H

#include <QtCore/QtGlobal>
#include <memory>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qsgmaterialshader.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QByteArray>
#include <QtCore/QScopedArrayPointer>
#include <QtCore/QScopedPointer>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtGui/qopenglshaderprogram.h>
#include <QtJambi/JavaAPI>
#include <QtQuick/qsgmaterial.h>
#include <QtJambi/RegistryAPI>


class QSGMaterialShader_shell : public QSGMaterialShader, public QtJambiShellInterface
{
public:
    QSGMaterialShader_shell();
    ~QSGMaterialShader_shell() override;

    void activate() override;
    const char*const * attributeNames() const override;
    void compile() override;
    void deactivate() override;
    const char* fragmentShader() const override;
    void initialize() override;
    void updateState(const QSGMaterialShader::RenderState& state0, QSGMaterial* newMaterial1, QSGMaterial* oldMaterial2) override;
    const char* vertexShader() const override;
    static void operator delete(void * ptr) noexcept;
private:
    mutable std::unique_ptr<QtJambiScope> __returnScope__fragmentShader_const;
    mutable std::unique_ptr<QtJambiScope> __returnScope__vertexShader_const;
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
    mutable QByteArray __qt_vertexShader;
    mutable QByteArray __qt_fragmentShader;
    mutable QByteArray __qt_attributeNameByteArrays;
    mutable QVector<const char *> __qt_attributeNames;
};

struct QSGMaterialShader_access : public QSGMaterialShader
{
    void __qt_setShaderSourceFile_QOpenGLShader_ShaderType_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jstring sourceFile1);
    void __qt_setShaderSourceFiles_QOpenGLShader_ShaderType_cref_QStringList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jobject sourceFiles1);
    void __qt_activate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobjectArray __qt_attributeNames(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_compile(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_deactivate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jstring __qt_fragmentShader(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_initialize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_updateState_cref_QSGMaterialShader_RenderState_QSGMaterial_ptr_QSGMaterial_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID state0, QtJambiNativeID newMaterial1, QtJambiNativeID oldMaterial2);
    jstring __qt_vertexShader(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QSGMATERIALSHADER_SHELL_H

==> qtjambi-quick-debuginfo-macos-5.15.20.jar: sources/QtJambiQuick/QSGMaterialShader_shell.h <==
#ifndef QSGMATERIALSHADER_SHELL_H
#define QSGMATERIALSHADER_SHELL_H

#include <QtCore/QtGlobal>
#include <memory>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qsgmaterialshader.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QByteArray>
#include <QtCore/QScopedArrayPointer>
#include <QtCore/QScopedPointer>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtGui/qopenglshaderprogram.h>
#include <QtJambi/JavaAPI>
#include <QtQuick/qsgmaterial.h>
#include <QtJambi/RegistryAPI>


class QSGMaterialShader_shell : public QSGMaterialShader, public QtJambiShellInterface
{
public:
    QSGMaterialShader_shell();
    ~QSGMaterialShader_shell() override;

    void activate() override;
    const char*const * attributeNames() const override;
    void compile() override;
    void deactivate() override;
    const char* fragmentShader() const override;
    void initialize() override;
    void updateState(const QSGMaterialShader::RenderState& state0, QSGMaterial* newMaterial1, QSGMaterial* oldMaterial2) override;
    const char* vertexShader() const override;
    static void operator delete(void * ptr) noexcept;
private:
    mutable std::unique_ptr<QtJambiScope> __returnScope__fragmentShader_const;
    mutable std::unique_ptr<QtJambiScope> __returnScope__vertexShader_const;
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
    mutable QByteArray __qt_vertexShader;
    mutable QByteArray __qt_fragmentShader;
    mutable QByteArray __qt_attributeNameByteArrays;
    mutable QVector<const char *> __qt_attributeNames;
};

struct QSGMaterialShader_access : public QSGMaterialShader
{
    void __qt_setShaderSourceFile_QOpenGLShader_ShaderType_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jstring sourceFile1);
    void __qt_setShaderSourceFiles_QOpenGLShader_ShaderType_cref_QStringList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jobject sourceFiles1);
    void __qt_activate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobjectArray __qt_attributeNames_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_compile(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_deactivate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jstring __qt_fragmentShader_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_initialize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_updateState_cref_QSGMaterialShader_RenderState_QSGMaterial_ptr_QSGMaterial_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID state0, QtJambiNativeID newMaterial1, QtJambiNativeID oldMaterial2);
    jstring __qt_vertexShader_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QSGMATERIALSHADER_SHELL_H
